@@ -23,9 +23,7 @@ use Const::Exporter enums => [
   EXCELLENT        => "EXCELLENT",
   GOOD             => "GOOD",
   NEEDS_ATTENTION  => "NEEDS_ATTENTION",
-  URGENT_ISSUES    => "URGENT_ISSUES",
-  NO_RECENT_UPLOAD => "NO_RECENT_UPLOAD",
-  FINISH_SETUP     => "FINISH_SETUP"
+  NO_RECENT_UPLOAD => "NO_RECENT_UPLOAD"
 ];
 
 1;
